export declare type RowName = string;
export declare type ColumnName = string;
export declare type DisplayMode = "list" | "matrix" | "none";
export declare type OptionType = "upload" | "filters" | "diff" | "displayMode";
export declare type Theme = {
    /** if true, reverses the standard ways colors are used */
    isDarkMode?: boolean;
    /** the primary background color to use for light areas of the application */
    light?: string;
    /** the primary background color to use for dark areas of the application */
    dark?: string;
    /** the accent color to use on light backgrounds */
    darkTheme?: string;
    /** the accent color to use on dark backgrounds */
    lightTheme?: string;
    /** the font family to use for all header text */
    headerFont?: string;
    /** the font family to use for all body text */
    bodyFont?: string;
};
export declare type ElementId = string;
export declare type Element = {
    id: ElementId;
    name: string;
    column: ColumnName;
    belongsToRows: RowName[];
    originRow: RowName;
};
export declare type Similarity = {
    similarElement: Element;
    score: number;
    differences: string[];
    splitBy: string | RegExp;
};
export declare type State = {
    columns: Set<ColumnName>;
    rows: Set<RowName>;
    elements: Record<ElementId, Element>;
    hiddenRows: Set<RowName>;
    hiddenColumns: Set<ColumnName>;
    displayMode: DisplayMode;
    enableDiffs: boolean;
    disableCollapsing: boolean;
    singleFileOnly: boolean;
    renderHtml: boolean;
    similarityGraph: Record<ElementId, Similarity[]>;
};
export declare type Context = {
    currentRow?: RowName;
    idx?: number;
};
